import pygame
 
# Inialize pygame font
pygame.font.init()
 
# Create a sprite group
btn_sprites = pygame.sprite.Group()
 
class Button(pygame.sprite.Sprite):
    def __init__(self, x=0, y=0, text='Button'):
        pygame.sprite.Sprite.__init__(self)
 
        # Set Button Attributes
        self.border_color = '#999999'
        self.bgcolor = 'blue'
        self.fgcolor = 'white'
        self.bg_hover_color = 'mediumblue'
        self.fg_hover_color = 'cyan'
        self.text = text
        self.x = x
        self.y = y
        self.type = None
        self.function = None
 
        # These two lines should not be changed
        self.pointer = pygame.mouse.get_pos()
        self.cursor = False
         
        # Setup the font and button text
        self.font = pygame.font.SysFont(None, 35)
        self.btn_text = self.font.render(self.text, True, self.fgcolor)
 
        # Get text width and height
        self.text_width, self.text_height = self.font.size(str(self.text))
 
        # Create the button surface
        self.button = pygame.Surface((self.text_width*2, self.text_height*2))
        self.button.fill(self.bgcolor)
 
        # Get button size
        self.button_rect = self.button.get_rect()
 
        # Get the center to place button text
        self.center_text = (
            self.button_rect.width/2 - self.text_width/2,
            self.button_rect.height/2 - self.text_height/2
        )
 
        # Blit text to button
        self.button.blit(self.btn_text, self.center_text)
 
        # Create the shadow image
        self.image = pygame.Surface((self.button_rect.width+5, self.button_rect.height+5)).convert()
        self.image.fill(self.border_color)
        self.rect = self.image.get_rect()
        self.image.set_alpha(200)
 
        # Get the center for button and shadow
        self.center_button = (
            self.rect.width/2 - self.button_rect.width/2,
            self.rect.height/2 - self.button_rect.height/2
        )
 
        # Add Button to sprite group
        btn_sprites.add(self)
         
 
    def update(self):
        ''' Method for updating button effects '''
 
        # Place the button
        self.rect.x = self.x
        self.rect.y = self.y
 
        # Get the pointer position
        self.pointer = pygame.mouse.get_pos()
 
        # If the pointer hovers over a button make highlight effect
        if self.rect.collidepoint(self.pointer):
            self.image.set_alpha(220)
            self.button.fill(self.bg_hover_color)
 
            # Effects for mouse click
            if pygame.mouse.get_pressed()[0] and self.function != None:
                self.image.set_colorkey(self.border_color)
                self.image.set_alpha(255)
            else:
                # Reset shadow
                self.image.set_colorkey()
        else:
            # Reset the button to default
            self.image.set_alpha(200)
            self.button.fill(self.bgcolor)
 
        # Update the button
        self.button.blit(self.btn_text, self.center_text)
        self.image.blit(self.button, self.center_button)