import pygame
from btn_class import Button, btn_sprites
 
# Setup pygame window
window_size = (1280, 780)
window = pygame.display.set_mode(window_size)
 
# Pygame caption
pygame.display.set_caption('My PyGame Window')
 
# Setup clock
clock = pygame.time.Clock()
fps = 60
 
# Window color
window_color = '#ffffff'
 
# Some flags
running = True
cursor = False
text = ''
 
# Create a sprite group
# This group is for displaying buttons only
allsprites = pygame.sprite.Group()
 
# Create some buttons
'''
    Button attributes with defaults:
        border_color = '#999999'
        bgcolor = 'blue'
        fgcolor = 'white'
        bg_hover_color = 'mediumblue'
        fg_hover_color = 'cyan'
        text = text
        x = x
        y = y
        type = None
        function = None
'''
 
def draw_text(text=None):
    '''
        Function will draw text to window
    '''
    font = pygame.font.SysFont(None, 40)
    string = font.render(text, True, 'black')
    string_width, string_height = font.size(str(text))
    window_width, window_height = window.get_rect().width, window.get_rect().height
     
    center = (
        window_width/2 - string_width/2,
        window_height/2 - string_height/2
    )
     
    window.blit(string, center)
 
 
btn1 = Button()
btn1.x = 20
btn1.y = 20
btn1.function = lambda: draw_text(f'You clicked {btn1.text.capitalize()}')
 
btn2 = Button(text='Button 2')
btn2.x = 220
btn2.y = 20
btn2.bgcolor = 'orange'
btn2.bg_hover_color = 'orangered'
btn2.function = lambda: draw_text(f'You clicked {btn2.text.capitalize()}')
 
btn3 = Button(text='Clear')
btn3.x = 460
btn3.y = 20
btn3.bgcolor = 'tomato'
btn3.bg_hover_color = 'red'
btn3.function = ''
btn3.type = 'clear'
 
# Add buttons to allsprites group
allsprites.add(btn1, btn2, btn3)
 
while running:
    window.fill(window_color)
 
    # Track pygame events
    for event in pygame.event.get():
        if event.type == pygame.QUIT:
            running = False
 
        # loop through btn_sprite group
        for button in btn_sprites:
 
            # Check for collisions/hover
            if button.rect.collidepoint(button.pointer):
 
                # We are over a button change pointer to hand
                button.cursor = True
 
                # Check if mouse button is clicked and we have a function to fire
                # Can add a type here to check for a specific button
                if pygame.mouse.get_pressed()[0] and button.function != None:
                    if button.type == 'clear':
                        text = ''
                    else:
                        text = f'You pressed {button.text}'                 
            else:
                # We are not over a button return pointer to default
                button.cursor = False
                pygame.mouse.set_cursor()
 
    # Loop through buttons and if flag is True change pointer to hand
    for button in btn_sprites:
        if button.cursor:
            pygame.mouse.set_cursor(pygame.SYSTEM_CURSOR_HAND)
 
    # Update allsprites and draw to window
    allsprites.update()
    allsprites.draw(window)
 
    draw_text(text)
 
    pygame.display.update()
    clock.tick(fps)